# Basic Antiword via libreoffice

This package is nothing more than a convenience wrapper around `libreoffice
--convert-to txt` which dumps to stdout, cleaning up the generated temporary
file as it goes.


I probably should have written it in bash, but there we go.
